# Ballad of asdf

> Once upon a time there was a programming language<br/>
> There were many versions of it<br/>
> So people wrote a version manager for it<br/>
> To switch between versions for projects<br/>
> Different, old, new.

> Then there came more programming languages<br/>
> So there came more version managers<br/>
> And many commands for them

> I installed a lot of them<br/>
> I learnt a lot of commands

> Then I said, just one more version manager<br/>
> Which I will write instead

> So, there came another version manager<br/>
> **asdf version manager** - <https://github.com/HashNuke/asdf>

> A version manager so extendable<br/>
> for which anyone can create a plugin<br/>
> To support their favourite language<br/>
> No more installing more version managers<br/>
> Or learning more commands

---

*This was the mail I wrote to a few friends to tell them about the project. Thanks to [@roshanvid](https://twitter.com/roshanvid) for suggesting that this go into the readme*
